#
# spec file for package readstat
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?sle_version} == 150000 || 0%{?suse_version} >= 1550
%bcond_without libcsv
%else
%bcond_with    libcsv
%endif

%define major 1
%define libname lib%{name}
%define libname_ver %{libname}%{major}
Name:           readstat
Version:        %{major}.1.9
Release:        1.1
Summary:        Command-line tool (+ C library) for converting SAS, Stata, and SPSS files
License:        MIT
URL:            https://github.com/WizardMac/ReadStat
Source0:        https://github.com/WizardMac/ReadStat/archive/v%{version}.tar.gz#/ReadStat-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-use-after-free.patch
BuildRequires:  autoconf
BuildRequires:  automake
%if %{with libcsv}
BuildRequires:  libcsv-devel
%endif
BuildRequires:  libtool
BuildRequires:  zlib-devel

%description
ReadStat is a command-line tool and C library for reading 
files from popular stats packages. Supported data formats include:

  - SAS: SAS7BDAT (binary file) and XPORT (transport file)
  - Stata: DTA (binary file) versions 104-119
  - SPSS: POR (portable file), SAV (binary file), and ZSAV (compressed binary)

Supported metadata formats include:

  - SAS: SAS7BCAT (catalog file) and .sas (command file)
  - Stata: .dct (dictionary file)
  - SPSS: .sps (command file)

There is also write support for all the data formats, but not the metadata
formats. The produced SAS7BDAT files still cannot be read by SAS.

%package -n    %{libname_ver}
Summary:        Command-line tool (+ C library) for converting SAS, Stata, and SPSS files

%description -n    %{libname_ver}
ReadStat is a command-line tool and C library for reading 
files from popular stats packages. Supported data formats include:

  - SAS: SAS7BDAT (binary file) and XPORT (transport file)
  - Stata: DTA (binary file) versions 104-119
  - SPSS: POR (portable file), SAV (binary file), and ZSAV (compressed binary)

Supported metadata formats include:

  - SAS: SAS7BCAT (catalog file) and .sas (command file)
  - Stata: .dct (dictionary file)
  - SPSS: .sps (command file)

There is also write support for all the data formats, but not the metadata
formats. The produced SAS7BDAT files still cannot be read by SAS.

%package devel
Summary:        Development files for %{name}
Requires:       %{libname_ver} = %{version}

%description devel
ReadStat is a command-line tool and C library for reading 
files from popular stats packages. Supported data formats include:

  - SAS: SAS7BDAT (binary file) and XPORT (transport file)
  - Stata: DTA (binary file) versions 104-119
  - SPSS: POR (portable file), SAV (binary file), and ZSAV (compressed binary)

Supported metadata formats include:

  - SAS: SAS7BCAT (catalog file) and .sas (command file)
  - Stata: .dct (dictionary file)
  - SPSS: .sps (command file)

There is also write support for all the data formats, but not the metadata
formats. The produced SAS7BDAT files still cannot be read by SAS.

This package contains files for development.

%prep
%autosetup -p1 -n ReadStat-%{version}

%build
NOCONFIGURE=1 ./autogen.sh
%configure
%make_build
# Build tests without executing
%make_build check TESTS=""

%install
%make_install

rm %{buildroot}%{_libdir}/%{libname}.la

%check
%make_build check

%post -n %{libname_ver} -p /sbin/ldconfig
%postun -n %{libname_ver} -p /sbin/ldconfig

%files devel
%doc README.md
%{_bindir}/extract_metadata
%{_bindir}/%{name}
%{_includedir}/%{name}.h
%{_libdir}/%{libname}.so
%{_mandir}/man1/extract_metadata.1%{?ext_man}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files -n %{libname_ver}
%license LICENSE
%{_libdir}/%{libname}.so.*

%changelog
* Sun Jan 26 2025 Christophe Marin <christophe@krop.fr>
- Update to 1.1.9
  * SAV reader: Improved support for Asian code pages
  * SAV reader: Improved support for Very Long String records
  * SAS reader: Improved support for RLE decompression
  * SAS reader: Support 16MiB page sizes
  * SAS catalog reader: Fix bugs reading big-endian files
  * SAS catalog reader: Allow formats with no labels
  * SAS catalog reader: Check for long names in 64-bit files
  * Improved compatibility with -Wstrict-prototypes
  * Replace sprintf with snprintf
- Add upstream change:
  * 0001-Fix-use-after-free.patch
* Sat Feb  4 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.1.8:
  * XPT reader/writer: Improved support for format strings
  * DTA writer: Fix off-by-one error in v,o indexing for
    string refs
  * SAV/DTA writers: Improved checking of non-ASCII characters
  * SAS7BDAT reader: Fix use-after-free error
  * Build: Link to libm on GNU systems
  * SAS commands: Support more syntax
  * SPSS commands: Make file names optional
- Add libcsv and zlib build dependencies where available
- Enable test suite
* Wed Jan  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Fix packaging to conform to SLPP guidelines.
- Set NOCONFIGURE=1 before running autogen.sh to ensure configure
  only runs once -- at the next step.
* Sun Nov 28 2021 andy great <andythe_great@pm.me>
- Update to version 1.1.7.
  * SAV writer: Permit missing ranges for integer variables #251
  * SAV writer: Fix format-truncation warning #247
  * DTA reader/writer: Improved support for string refs on older
    platforms
  * DTA reader: Fix incorrect ordering in StrL comparison
    functions #248
  * SAS7BDAT writer: Improved support for tagged missing values on
    big-endian platforms
  * SAS readers: Allow header sizes up to 16MiB #249
  * Visual Studio: Fix paths to make them consistent between x86
    and x64 archs #242
- Update to version 1.1.6.
  * Regenerate parsers with Ragel 7 and update build script
  * SAS7BDAT reader: Improved large file support on Windows #226
  * SAV reader: Skip null bytes in UTF-8 data tidyverse/haven#560
  * SAV reader: Fix hang (oss-fuzz/23485)
  * DTA reader: Disallow str0 type (fixes hang)
  * DTA reader: Fix encoding error when garbage values are present
    beyond the end of a string
  * Command file readers: Fix integer overflow (oss-fuzz/15778)
  * extract_metadata: Implement duration support #223
    (thanks to @basgys)
  * Support for SAS files created with SAS Visual Forecaster #232
  * Report format widths for date/time SAS formats #233
  * Document the meaning of a -1 return value from
    readstat_get_row_count #234
* Sun Dec 27 2020 andy great <andythe_great@pm.me>
- Initial package release.
